@@ -10,8 +10,9 @@ import sklearn.cluster
 from dask import compute
 from sklearn.base import BaseEstimator, TransformerMixin
 from sklearn.utils.extmath import squared_norm
+from sklearn.utils.validation import check_is_fitted
 
-from .._compat import SK_024, blockwise, check_is_fitted
+from .._compat import blockwise
 from .._utils import draw_seed
 from ..metrics import (
     euclidean_distances,
@@ -19,11 +20,7 @@ from ..metrics import (
     pairwise_distances_argmin_min,
 )
 from ..utils import _timed, _timer, check_array, row_norms
-
-if SK_024:
-    from ._compat import _kmeans_plusplus
-else:
-    from ._compat import _k_init as _kmeans_plusplus
+from ._compat import _kmeans_plusplus
 
 import numba  # isort:skip (see https://github.com/dask/dask-ml/pull/577)
 
@@ -86,7 +83,7 @@ class KMeans(TransformerMixin, BaseEstimator):
         A dask array with the index position in ``cluster_centers_`` this
         sample belongs to.
 
-    intertia_ : float
+    inertia_ : float
         Sum of distances of samples to their closest cluster center.
 
     n_iter_ : int
@@ -393,8 +390,7 @@ def init_pp(X, n_clusters, random_state):
             random_state=random_state,
             x_squared_norms=x_squared_norms,
         )
-        if SK_024:
-            centers, _ = centers
+        centers, _ = centers
 
     return centers
 
