@@ -24,8 +24,9 @@ from sklearn.metrics import check_scoring
 from sklearn.model_selection import ParameterGrid, ParameterSampler
 from sklearn.utils import check_random_state
 from sklearn.utils.metaestimators import if_delegate_has_method
+from sklearn.utils.validation import check_is_fitted
 
-from .._compat import check_is_fitted, dummy_context
+from .._compat import DISTRIBUTED_2021_02_0, annotate, dummy_context
 from .._typing import ArrayLike, Int
 from .._utils import LoggingContext
 from ..wrappers import ParallelPostFit
@@ -127,7 +128,7 @@ def _score(
 
 
 def _create_model(model: Model, ident: Int, **params: Params) -> Tuple[Model, Meta]:
-    """ Create a model by cloning and then setting params """
+    """Create a model by cloning and then setting params"""
     with log_errors():
         model = clone(model).set_params(**params)
         return model, {"model_id": ident, "params": params, "partial_fit_calls": 0}
@@ -239,13 +240,18 @@ async def _fit(
     for ident, model in models.items():
         model = d_partial_fit(model, X_future, y_future, fit_params)
         score = d_score(model, X_test, y_test, scorer)
-        spec = d_partial_fit(model, X_future_2, y_future_2, fit_params)
+        with annotate(priority=-1):
+            spec = d_partial_fit(model, X_future_2, y_future_2, fit_params)
         _models[ident] = model
         _scores[ident] = score
         _specs[ident] = spec
-    _models, _scores, _specs = dask.persist(
-        _models, _scores, _specs, priority={tuple(_specs.values()): -1}
-    )
+
+    if DISTRIBUTED_2021_02_0:
+        _models, _scores, _specs = dask.persist(_models, _scores, _specs)
+    else:
+        _models, _scores, _specs = dask.persist(
+            _models, _scores, _specs, priority={tuple(_specs.values()): -1}
+        )
     _models = {k: list(v.dask.values())[0] for k, v in _models.items()}
     _scores = {k: list(v.dask.values())[0] for k, v in _scores.items()}
     _specs = {k: list(v.dask.values())[0] for k, v in _specs.items()}
@@ -301,14 +307,19 @@ async def _fit(
                     model = d_partial_fit(model, X_future, y_future, fit_params)
                 score = d_score(model, X_test, y_test, scorer)
                 X_future, y_future = get_futures(start + k)
-                spec = d_partial_fit(model, X_future, y_future, fit_params)
+                with annotate(priority=-1):
+                    spec = d_partial_fit(model, X_future, y_future, fit_params)
                 _models[ident] = model
                 _scores[ident] = score
                 _specs[ident] = spec
 
-        _models2, _scores2, _specs2 = dask.persist(
-            _models, _scores, _specs, priority={tuple(_specs.values()): -1}
-        )
+        if DISTRIBUTED_2021_02_0:
+            _models2, _scores2, _specs2 = dask.persist(_models, _scores, _specs)
+        else:
+            _models2, _scores2, _specs2 = dask.persist(
+                _models, _scores, _specs, priority={tuple(_specs.values()): -1}
+            )
+
         _models2 = {
             k: v if isinstance(v, Future) else list(v.dask.values())[0]
             for k, v in _models2.items()
@@ -504,6 +515,9 @@ class BaseIncrementalSearchCV(ParallelPostFit):
         tol=1e-3,
         verbose=False,
         prefix="",
+        predict_meta=None,
+        predict_proba_meta=None,
+        transform_meta=None,
     ):
         self.parameters = parameters
         self.test_size = test_size
@@ -513,7 +527,13 @@ class BaseIncrementalSearchCV(ParallelPostFit):
         self.tol = tol
         self.verbose = verbose
         self.prefix = prefix
-        super(BaseIncrementalSearchCV, self).__init__(estimator, scoring=scoring)
+        super(BaseIncrementalSearchCV, self).__init__(
+            estimator,
+            scoring=scoring,
+            predict_meta=predict_meta,
+            predict_proba_meta=predict_proba_meta,
+            transform_meta=transform_meta,
+        )
 
     async def _validate_parameters(self, X, y):
         if (self.max_iter is not None) and self.max_iter < 1:
@@ -835,6 +855,24 @@ class IncrementalSearchCV(BaseIncrementalSearchCV):
     prefix : str, optional, default=""
         While logging, add ``prefix`` to each message.
 
+    predict_meta: pd.Series, pd.DataFrame, np.array deafult: None(infer)
+        An empty ``pd.Series``, ``pd.DataFrame``, ``np.array`` that matches the output
+        type of the estimators ``predict`` call.
+        This meta is necessary for  for some estimators to work with
+        ``dask.dataframe`` and ``dask.array``
+
+    predict_proba_meta: pd.Series, pd.DataFrame, np.array deafult: None(infer)
+        An empty ``pd.Series``, ``pd.DataFrame``, ``np.array`` that matches the output
+        type of the estimators ``predict_proba`` call.
+        This meta is necessary for  for some estimators to work with
+        ``dask.dataframe`` and ``dask.array``
+
+    transform_meta: pd.Series, pd.DataFrame, np.array deafult: None(infer)
+        An empty ``pd.Series``, ``pd.DataFrame``, ``np.array`` that matches the output
+        type of the estimators ``transform`` call.
+        This meta is necessary for  for some estimators to work with
+        ``dask.dataframe`` and ``dask.array``
+
     Attributes
     ----------
     cv_results_ : dict of np.ndarrays
@@ -882,7 +920,7 @@ class IncrementalSearchCV(BaseIncrementalSearchCV):
         retained by the "inverse decay" algorithm.
 
     best_score_ : float
-        Score achieved by ``best_estimator_`` on the vaidation set after the
+        Score achieved by ``best_estimator_`` on the validation set after the
         final call to ``partial_fit``.
 
     best_index_ : int
@@ -946,7 +984,7 @@ class IncrementalSearchCV(BaseIncrementalSearchCV):
 
     For example, setting ``tol=0`` and ``patience=2`` means training will stop
     after two consecutive calls to ``model.partial_fit`` without improvement,
-    or when ``max_iter`` total calls to ``model.parital_fit`` are reached.
+    or when ``max_iter`` total calls to ``model.partial_fit`` are reached.
 
     """
 
@@ -966,6 +1004,9 @@ class IncrementalSearchCV(BaseIncrementalSearchCV):
         verbose=False,
         prefix="",
         scores_per_fit=None,
+        predict_meta=None,
+        predict_proba_meta=None,
+        transform_meta=None,
     ):
 
         self.n_initial_parameters = n_initial_parameters
@@ -984,6 +1025,9 @@ class IncrementalSearchCV(BaseIncrementalSearchCV):
             tol=tol,
             verbose=verbose,
             prefix=prefix,
+            predict_meta=predict_meta,
+            predict_proba_meta=predict_proba_meta,
+            transform_meta=transform_meta,
         )
 
     def _decay_deprecated(self):
@@ -1195,7 +1239,7 @@ class InverseDecaySearchCV(IncrementalSearchCV):
         Higher `decay_rate` will result in lower training times, at the cost
         of worse models.
 
-        The default ``decay_rate=1.0`` is chosen because it has some theoritical
+        The default ``decay_rate=1.0`` is chosen because it has some theoretical
         motivation [1]_.
 
     Attributes
@@ -1245,7 +1289,7 @@ class InverseDecaySearchCV(IncrementalSearchCV):
         retained by the "inverse decay" algorithm.
 
     best_score_ : float
-        Score achieved by ``best_estimator_`` on the vaidation set after the
+        Score achieved by ``best_estimator_`` on the validation set after the
         final call to ``partial_fit``.
 
     best_index_ : int
@@ -1268,7 +1312,7 @@ class InverseDecaySearchCV(IncrementalSearchCV):
     Notes
     -----
     When ``decay_rate==1``, this class approximates the
-    number of ``partial_fit`` calls that :class:`SuccesiveHalvingSearchCV`
+    number of ``partial_fit`` calls that :class:`SuccessiveHalvingSearchCV`
     performs. If ``n_initial_parameters`` is configured properly with
     ``decay_rate=1``, it's possible this class will mirror the most aggressive
     bracket of :class:`HyperbandSearchCV`. This might yield good results
@@ -1327,7 +1371,7 @@ class InverseDecaySearchCV(IncrementalSearchCV):
             start = self.n_initial_parameters
 
         def inverse(time):
-            """ Decrease target number of models inversely with time """
+            """Decrease target number of models inversely with time"""
             return int(start / (1 + time) ** self.decay_rate)
 
         example = toolz.first(info.values())
