@@ -15,7 +15,13 @@ from dask.delayed import delayed
 from dask.distributed import as_completed
 from dask.utils import derived_from
 from sklearn import model_selection
-from sklearn.base import BaseEstimator, MetaEstimatorMixin, clone, is_classifier
+from sklearn.base import (
+    BaseEstimator,
+    MetaEstimatorMixin,
+    _is_pairwise,
+    clone,
+    is_classifier,
+)
 from sklearn.exceptions import NotFittedError
 from sklearn.model_selection._search import BaseSearchCV, _check_param_grid
 from sklearn.model_selection._split import (
@@ -33,9 +39,9 @@ from sklearn.model_selection._split import (
 from sklearn.pipeline import FeatureUnion, Pipeline
 from sklearn.utils.metaestimators import if_delegate_has_method
 from sklearn.utils.multiclass import type_of_target
-from sklearn.utils.validation import _num_samples
+from sklearn.utils.validation import _num_samples, check_is_fitted
 
-from .._compat import SK_024, SK_VERSION, check_is_fitted
+from .._compat import SK_VERSION
 from ._normalize import normalize_estimator
 from .methods import (
     MISSING,
@@ -55,9 +61,6 @@ from .methods import (
 )
 from .utils import DeprecationDict, is_dask_collection, to_indexable, to_keys, unzip
 
-if SK_024:
-    from sklearn.base import _is_pairwise
-
 logger = logging.getLogger(__name__)
 
 try:
@@ -200,10 +203,7 @@ def build_cv_graph(
     X, y, groups = to_indexable(X, y, groups)
     cv = check_cv(cv, y, is_classifier(estimator))
     # "pairwise" estimators require a different graph for CV splitting
-    if SK_024:
-        is_pairwise = _is_pairwise(estimator)
-    else:
-        is_pairwise = getattr(estimator, "_pairwise", False)
+    is_pairwise = _is_pairwise(estimator)
 
     dsk = {}
     X_name, y_name, groups_name = to_keys(dsk, X, y, groups)
