@@ -1,6 +1,8 @@
 from __future__ import division
 
+import collections
 import multiprocessing
+import numbers
 from collections import OrderedDict
 from distutils.version import LooseVersion
 from typing import Any, List, Optional, Sequence, Union
@@ -15,20 +17,21 @@ from dask.array import nanmean, nanvar
 from pandas.api.types import is_categorical_dtype
 from scipy import stats
 from sklearn.base import BaseEstimator, TransformerMixin
-from sklearn.utils.validation import check_random_state
+from sklearn.utils.validation import check_is_fitted, check_random_state
 
-from dask_ml._compat import blockwise, check_is_fitted
+from dask_ml._compat import blockwise
 from dask_ml._utils import copy_learned_attributes
 from dask_ml.utils import check_array, handle_zeros_in_scale
 
-from .._typing import ArrayLike, DataFrameType, SeriesType
+from .._typing import ArrayLike, DataFrameType, NDArrayOrScalar, SeriesType
+from ..base import DaskMLBaseMixin
 
 _PANDAS_VERSION = LooseVersion(pd.__version__)
 _HAS_CTD = _PANDAS_VERSION >= "0.21.0"
 BOUNDS_THRESHOLD = 1e-7
 
 
-def _handle_zeros_in_scale(scale: np.ndarray, copy=True):
+def _handle_zeros_in_scale(scale: NDArrayOrScalar, copy=True):
     """Makes sure that whenever scale is zero, we handle it correctly.
 
     This happens in most scalers when we have constant features."""
@@ -46,7 +49,7 @@ def _handle_zeros_in_scale(scale: np.ndarray, copy=True):
         return scale
 
 
-class StandardScaler(sklearn.preprocessing.StandardScaler):
+class StandardScaler(DaskMLBaseMixin, sklearn.preprocessing.StandardScaler):
 
     __doc__ = sklearn.preprocessing.StandardScaler.__doc__
 
@@ -56,6 +59,15 @@ class StandardScaler(sklearn.preprocessing.StandardScaler):
         y: Optional[Union[ArrayLike, SeriesType]] = None,
     ) -> "StandardScaler":
         self._reset()
+        X = self._validate_data(
+            X,
+            estimator=self,
+            accept_dask_array=True,
+            accept_dask_dataframe=True,
+            accept_unknown_chunks=True,
+            preserve_pandas_dataframe=True,
+        )
+
         attributes = OrderedDict()
         if isinstance(X, (pd.DataFrame, dd.DataFrame)):
             X = X.values
@@ -71,11 +83,11 @@ class StandardScaler(sklearn.preprocessing.StandardScaler):
             attributes["scale_"] = scale_
             attributes["var_"] = var_
 
-        attributes["n_samples_seen_"] = np.nan
+        attributes["n_samples_seen_"] = X.shape[0]
         values = compute(*attributes.values())
         for k, v in zip(attributes, values):
             setattr(self, k, v)
-        self.n_features_in_ = X.shape[1]
+        self.n_features_in_: int = X.shape[1]
         return self
 
     def partial_fit(
@@ -137,12 +149,12 @@ class MinMaxScaler(sklearn.preprocessing.MinMaxScaler):
         attributes["data_range_"] = data_range
         attributes["scale_"] = scale
         attributes["min_"] = feature_range[0] - data_min * scale
-        attributes["n_samples_seen_"] = np.nan
+        attributes["n_samples_seen_"] = X.shape[0]
 
         values = compute(*attributes.values())
         for k, v in zip(attributes, values):
             setattr(self, k, v)
-        self.n_features_in_ = X.shape[1]
+        self.n_features_in_: int = X.shape[1]
         return self
 
     def partial_fit(
@@ -227,7 +239,7 @@ class RobustScaler(sklearn.preprocessing.RobustScaler):
         self.center_: List[float] = quantiles[:, 1]
         self.scale_: List[float] = quantiles[:, 2] - quantiles[:, 0]
         self.scale_ = _handle_zeros_in_scale(self.scale_, copy=False)
-        self.n_features_in_ = X.shape[1]
+        self.n_features_in_: int = X.shape[1]
         return self
 
     def transform(
@@ -246,7 +258,7 @@ class RobustScaler(sklearn.preprocessing.RobustScaler):
         This implementation was copied and modified from Scikit-Learn.
 
         See License information here:
-        https://github.com/scikit-learn/scikit-learn/blob/master/README.rst
+        https://github.com/scikit-learn/scikit-learn/blob/main/README.rst
         """
         if self.with_centering:
             check_is_fitted(self, "center_")
@@ -277,7 +289,7 @@ class RobustScaler(sklearn.preprocessing.RobustScaler):
         This implementation was copied and modified from Scikit-Learn.
 
         See License information here:
-        https://github.com/scikit-learn/scikit-learn/blob/master/README.rst
+        https://github.com/scikit-learn/scikit-learn/blob/main/README.rst
         """
         check_is_fitted(self, ["center_", "scale_"])
 
@@ -338,6 +350,7 @@ class QuantileTransformer(sklearn.preprocessing.QuantileTransformer):
         references = self.references_ * 100
         quantiles = [da.percentile(col, references) for col in X.T]
         (self.quantiles_,) = compute(da.vstack(quantiles).T)
+        return None
 
     def _transform(
         self, X: Union[ArrayLike, DataFrameType], inverse: bool = False
@@ -352,7 +365,7 @@ class QuantileTransformer(sklearn.preprocessing.QuantileTransformer):
         return da.vstack(transformed, allow_unknown_chunksizes=True).T
 
     def _transform_col(
-        self, X_col: ArrayLike, quantiles: ArrayLike, inverse: bool
+        self, X_col: da.Array, quantiles: ArrayLike, inverse: bool
     ) -> ArrayLike:
         output_distribution = self.output_distribution
 
@@ -761,7 +774,7 @@ class DummyEncoder(BaseEstimator, TransformerMixin):
             if unknown:
                 lengths = blockwise(len, "i", X[:, 0], "i", dtype="i8").compute()
                 X = X.copy()
-                chunks: ArrayLike = (tuple(lengths), X.chunks[1])
+                chunks: tuple = (tuple(lengths), X.chunks[1])
                 X._chunks = chunks
 
             X = dd.from_dask_array(X, columns=self.transformed_columns_)
@@ -769,9 +782,9 @@ class DummyEncoder(BaseEstimator, TransformerMixin):
         big = isinstance(X, dd.DataFrame)
 
         if big:
-            chunks = np.array(X.divisions)
-            chunks[-1] = chunks[-1] + 1
-            chunks = tuple(chunks[1:] - chunks[:-1])
+            divisions = np.array(X.divisions)
+            divisions[-1] = divisions[-1] + 1
+            chunks = tuple(divisions[1:] - divisions[:-1])
 
         non_cat = X[list(self.non_categorical_columns_)]
 
@@ -986,7 +999,7 @@ class OrdinalEncoder(BaseEstimator, TransformerMixin):
             if unknown:
                 lengths = blockwise(len, "i", X[:, 0], "i", dtype="i8").compute()
                 X = X.copy()
-                chunks: ArrayLike = (tuple(lengths), X.chunks[1])
+                chunks: tuple = (tuple(lengths), X.chunks[1])
                 X._chunks = chunks
 
             X = dd.from_dask_array(X, columns=self.columns_)
@@ -994,9 +1007,9 @@ class OrdinalEncoder(BaseEstimator, TransformerMixin):
         big = isinstance(X, dd.DataFrame)
 
         if big:
-            chunks = np.array(X.divisions)
-            chunks[-1] = chunks[-1] + 1
-            chunks = tuple(chunks[1:] - chunks[:-1])
+            divisions = np.array(X.divisions)
+            divisions[-1] = divisions[-1] + 1
+            chunks = tuple(divisions[1:] - divisions[:-1])
 
         X = X.copy()
         for col in self.categorical_columns_:
@@ -1035,7 +1048,7 @@ class OrdinalEncoder(BaseEstimator, TransformerMixin):
         return X
 
 
-class PolynomialFeatures(sklearn.preprocessing.PolynomialFeatures):
+class PolynomialFeatures(DaskMLBaseMixin, sklearn.preprocessing.PolynomialFeatures):
     """preserve_dataframe : boolean
         If True, preserve pandas and dask dataframes after transforming.
         Using False (default) returns numpy or dask arrays and mimics
@@ -1071,6 +1084,45 @@ class PolynomialFeatures(sklearn.preprocessing.PolynomialFeatures):
             interaction_only=self.interaction_only,
             include_bias=self.include_bias,
         )
+        X = self._validate_data(
+            X,
+            estimator=self,
+            accept_dask_array=True,
+            accept_dask_dataframe=True,
+            accept_unknown_chunks=True,
+            preserve_pandas_dataframe=True,
+        )
+
+        if isinstance(self.degree, numbers.Integral):
+            if self.degree < 0:
+                raise ValueError(
+                    f"degree must be a non-negative integer, got {self.degree}."
+                )
+            self._min_degree = 0
+            self._max_degree = self.degree
+        elif (
+            isinstance(self.degree, collections.abc.Iterable) and len(self.degree) == 2
+        ):
+            self._min_degree, self._max_degree = self.degree
+            if not (
+                isinstance(self._min_degree, numbers.Integral)
+                and isinstance(self._max_degree, numbers.Integral)
+                and self._min_degree >= 0
+                and self._min_degree <= self._max_degree
+            ):
+                raise ValueError(
+                    "degree=(min_degree, max_degree) must "
+                    "be non-negative integers that fulfil "
+                    "min_degree <= max_degree, got "
+                    f"{self.degree}."
+                )
+        else:
+            raise ValueError(
+                "degree must be a non-negative int or tuple "
+                "(min_degree, max_degree), got "
+                f"{self.degree}."
+            )
+
         X_sample = X
         if isinstance(X, dd.DataFrame):
             X_sample = X._meta_nonempty
@@ -1088,19 +1140,19 @@ class PolynomialFeatures(sklearn.preprocessing.PolynomialFeatures):
         y: Optional[Union[ArrayLike, SeriesType]] = None,
     ) -> Union[ArrayLike, DataFrameType]:
         if isinstance(X, da.Array):
-            n_cols = len(self._transformer.get_feature_names())
+            n_cols = len(self._transformer.get_feature_names_out())
             X = check_array(X, accept_multiple_blocks=False, accept_unknown_chunks=True)
             chunks = (X.chunks[0], n_cols)
             XP = X.map_blocks(self._transformer.transform, dtype=X.dtype, chunks=chunks)
         elif isinstance(X, pd.DataFrame):
             XP = X.pipe(self._transformer.transform)
             if self.preserve_dataframe:
-                columns = self._transformer.get_feature_names(X.columns)
+                columns = self._transformer.get_feature_names_out(X.columns)
                 XP = pd.DataFrame(data=XP, columns=columns, index=X.index)
         elif isinstance(X, dd.DataFrame):
             XP = X.map_partitions(self._transformer.transform)
             if self.preserve_dataframe:
-                columns = self._transformer.get_feature_names(X.columns)
+                columns = self._transformer.get_feature_names_out(X.columns)
                 XP = dd.from_dask_array(XP, columns, X.index)
         else:
             # typically X is instance of np.ndarray
